Usage — odoo_score 2.0.6 documentation

# Usage

# odoo_shell usage

    usage: odoo_shell.py [-h] [-A python_name] [-c file] [-d file] [-n] [-q] [-V]
                         [-v] [-w file] [-z name] [-1 PARAM_1] [-2 PARAM_2]
                         [-3 PARAM_3] [-4 PARAM_4] [-5 PARAM_5] [-6 PARAM_6]

    Odoo test environment

    optional arguments:
      -h, --help            show this help message and exit
      -A python_name, --action python_name
                            internal action to execute
      -c file, --config file
                            configuration command file
      -d file, --dbname file
                            DB name to connect
      -n, --dry-run         do nothing (dry-run)
      -q, --quiet           silent mode
      -V, --version         show program's version number and exit
      -v, --verbose         verbose mode
      -w file, --src-config file
                            Source DB configuration file
      -z name, --src-db_name name
                            Source database name
      -1 PARAM_1, --param-1 PARAM_1
                            value to pass to called function
      -2 PARAM_2, --param-2 PARAM_2
                            value to pass to called function
      -3 PARAM_3, --param-3 PARAM_3
                            value to pass to called function
      -4 PARAM_4, --param-4 PARAM_4
                            value to pass to called function
      -5 PARAM_5, --param-5 PARAM_5
                            value to pass to called function
      -6 PARAM_6, --param-6 PARAM_6
                            value to pass to called function

This module is part of tools project.

Last Update / Ultimo aggiornamento: 2023-04-15